{ FoxClone
  Copyright (C) 2019, 2020 Andy Hardwick
  This source is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free
  Software Foundation; either version 2 of the License, or (at your option)
  any later version.
  This code is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.
  A copy of the GNU General Public License is available on the World Wide Web
  at <http://www.gnu.org/copyleft/gpl.html>. You can also obtain it by writing
  to the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  Boston, MA 02110-1335, USA.
}

{-------------------------------------------------------------------------------
UNIT CONFFORM
This is the confirm window that pops up as the 'last chance to change your mind' before a backup,
restore or clone starts.

Changes:

V1.0 - 05 Jun 2019
-------------------------------------------------------------------------------}
unit confform;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, Forms, Controls, Graphics, Dialogs, ExtCtrls, StdCtrls, utilities;

type
  Tconfform = class(TForm)
    cDriveImg, cFileImg, cArrowImg : TImage;
    cCancelBtn, OkBtn : TButton;
    SourceLbl, DestLbl,DestFileLbl : Tlabel;
    PartListBox : TListBox;
  private
    procedure CancelBtnCK(Sender : TObject);
    procedure OkBtnCK(Sender : TObject);
  public
    constructor Create(TheOwner: TComponent);
  end;

var
  ConfirmForm: Tconfform;

implementation

{$R *.lfm}
uses
  backup, restore, clone;
{-------------------------------------------------------------------------------
CONSTRUCTOR
Creates the confirm window. Initial sizing and placing of objects is set up for backup.
Restore and clone adjust the position of objects on the form.

Used by: unit backup - BackConfirm
         unit clone - CloneDiskConfirm, CloneFileConfirm
         unit restore - RestConfirm

V1.0 - 05 Jun 2019
V1.1 - 24 Sep 2020 : BorderStyle added to stop window resizing
-------------------------------------------------------------------------------}
constructor TConfform.Create(TheOwner: TComponent);
const
  cHeight = 220;
  cWidth = 400;
begin
  inherited CreateNew(TheOwner,1);
  BorderStyle:= bsSingle;
  Font.Name:= 'Noto Sans';
  Font.Size:= 10;
  Caption:= 'Confirm Selection';
  Position:= poScreenCenter;
  SetInitialBounds(0,0,cWidth,cHeight);
  TabStop:= false;
  cDriveImg:=TImage.Create(Self);
  with cDriveImg do
       begin
         Name:='Drive';
         Parent:= self;
         left:= 20;
         top:= 15;
         visible:= true;
         autosize:= false; // this overrides height width and makes full size or fit window
         Picture.LoadFromFile(PartImgFile);
       end;
  cFileImg:=TImage.Create(Self);
  with cFileImg do
       begin
         Name:='File';
         Parent:= Self;
         left:= 20;
         top:= 115;
         autosize:= false;
         Picture.LoadFromFile(FileImgFile);
       end;
  cArrowImg:=TImage.Create(Self);
  with cArrowImg do
       begin
         Name:='Arrow';
         Parent:= Self;
         left:= 20;
         top:= 58;
         autosize:= false; // this overrides height width and makes full size or fit window
         Picture.LoadFromFile(DnArrowImgFile);
       end;
  OkBtn:= TButton.Create(Self);
  with OkBtn do
       begin
         TabStop:= true;
         Default:= true;
         Parent:= Self;
         Width:= 80;
         Left:= 290;
         Top:= 170;
         Height:= 30;
         Show;
         Caption:= 'OK';
         Enabled:= true;
         OnClick := @OkBtnCK;
         Visible:= true;
         ModalResult:= mrOK;
       end;
  cCancelBtn:= TButton.Create(Self);
  with cCancelBtn do
       begin
         TabStop:= true;
         Cancel:= true;
         Parent:= Self;
         Width:= 80;
         Left:= 200;
         Top:= 170;
         Height:= 30;
         Show;
         Caption:= 'Cancel';
         Enabled:= true;
         OnClick := @CancelBtnCK;
         Visible:= true;
       end;
  SourceLbl:= TLabel.Create(Self);
  with SourceLbl do
       begin
         Parent:= Self;
         Width:= 80;
         Left:= 100;
         Top:= 10;
         Height:= 30;
         Show;
         Caption:= 'Source Drive:';
         Enabled:= true;
         Visible:= true;
       end;
  PartListBox:= TListBox.Create(Self);
  with PartListBox do
       begin
         TabStop:= false;
         Parent:= Self;
         Width:= 268;
         Left:= 100;
         Top:= 30;
         Height:= 80;
         ItemHeight:= 12;
         Style:=lbOwnerDrawVariable; // required for itemheight to work
         Show;
         Enabled:= true;
         Visible:= true;
       end;
  DestLbl:= TLabel.Create(Self);
  with DestLbl do
       begin
         Parent:= Self;
         Width:= 80;
         Left:= 100;
         Top:= 120;
         Height:= 30;
         Show;
         Caption:= 'Destination Drive: ';
         Enabled:= true; //turn off until needed
         Visible:= true; //not visible until needed
       end;
  DestFileLbl:= TLabel.Create(Self);
  with DestFileLbl do
       begin
         Parent:= Self;
         Width:= 80;   //was 80
         Left:= 100;
         Top:= 140;
         Height:= 30;
         Show;
         Caption:= 'File: ';
         Enabled:= true;
         Visible:= true;
    end;
end; // constructor
{-------------------------------------------------------------------------------
PROCEDURE CANCELBTNCK
Event handler for the cancel button, closes the form.

Used by: the confform constructor

V1.0 - 05 Jun 2019
-------------------------------------------------------------------------------}
procedure Tconfform.CancelBtnCK(Sender : TObject);
begin
  Close;
end; //end procedure Tconfform.CancelBtnCK
{-------------------------------------------------------------------------------
PROCEDURE OKBTNCK
Event handler for the ok button = ok to proceed, what happens next is determined by CurrentAction, a
global variable (declared in utilities) whose value is set elsewhere.

Used by: the confform constructor

V1.0 - 05 Jun 2019
-------------------------------------------------------------------------------}
procedure Tconfform.OkBtnCK(Sender : TObject);
begin
  case CurrentAction of
       acBack : BackBackup;
       acRest : RestRestore;
       acClone : CloneDiskToDisk;
       acFileClone : CloneFileToDisk;
  end;
end; //end procedure Tconfform.OkBtnCK
end.

