{ FoxClone
  Copyright (C) 2019, 2020 Andy Hardwick
  This source is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free
  Software Foundation; either version 2 of the License, or (at your option)
  any later version.
  This code is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.
  A copy of the GNU General Public License is available on the World Wide Web
  at <http://www.gnu.org/copyleft/gpl.html>. You can also obtain it by writing
  to the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  Boston, MA 02110-1335, USA.
}

{-------------------------------------------------------------------------------
UNIT NOTEFORM
Displays a window with a text box - for the user to either enter notes on a backup or
view the note when doing a restore.

Changes:

V1.0 - 28 May 2019
-------------------------------------------------------------------------------}
unit noteform;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, Forms, Controls, Graphics, Dialogs, StdCtrls, utilities, progform;

type
  TNoteForm = class(TForm)
    BackMemo : TMemo;
    CancelButton,
    SaveButton : TButton;
  private
    procedure noteCancel(Sender: TObject);
    procedure noteSave(Sender: TObject);
  public
    constructor Create(TheOwner: TComponent);
  end;

implementation

{$R *.lfm}
{-------------------------------------------------------------------------------
CONSTRUCTOR
Creates the noteform.

Used by: unit progform - ProgFmAddNote

V1.0 - 28 May 2019
-------------------------------------------------------------------------------}
constructor TNoteForm.Create(TheOwner: TComponent);
const
  nHeight : longint = 250;  //main window initial height
  nWidth : longint = 400;   //main window initial width
  Lmargin = 20; //left margin for objects in the main window
begin
  inherited CreateNew(TheOwner,1);
  Font.Name:= 'Noto Sans';
  Font.Size:= 10;
  TabStop:= false;
  Caption:= 'Backup Notes:'; //caption for the title bar
  Position:=poScreenCenter;
  SetInitialBounds(0,0,nWidth,nHeight); //defines initial size
  Visible:= true;
  BackMemo := TMemo.Create(ProgressFm);
  with BackMemo do
       begin
         WordWrap:= True;
         Parent:= Self;
         Left:= Lmargin;
         Top:= 20;
         Width:= nWidth - 2 * Lmargin;
         Height:= nHeight - 90;
         Scrollbars:= ssAutoBoth; //changed 16/1/21 when doing view logs on verify
         Show;
       end;
  CancelButton:= TButton.Create(ProgressFm);
  with CancelButton do
       begin
         Cancel:= true;
         parent:= Self;
         Width:= 80;
         Left:= 210;
         Top:= BackMemo.Top + 180;
         Height:= 30;
         Show;
         Caption:= 'Cancel';
         OnClick := @noteCancel;
        end;
  SaveButton:= TButton.Create(ProgressFm);
  with SaveButton do
       begin
         Default:= true;
         parent:= Self;
         Width:= 80;
         Left:= 300;
         Top:= BackMemo.Top + 180;
         Height:= 30;
         Show;
         Caption:= 'Save';
         Enabled:= true; //turn off until needed
         OnClick := @noteSave;
       end;
  if FileExists(BackFileName + '.note.txt') then
     BackMemo.Lines.LoadFromFile(BackFileName + '.note.txt');
end; //end constructor
{-------------------------------------------------------------------------------
PROCEDURE - TNOTEFORM.NOTECANCEL

Event handler for the cancel button on the note form. Closes the form.

Used by: noteform constructor

V1.0 - 28 May 2019
-------------------------------------------------------------------------------}
procedure TNoteForm.noteCancel(Sender: TObject);
begin
  Close;
end; //end procedure TNoteForm.noteCancel
{-------------------------------------------------------------------------------
PROCEDURE - TNOTEFORM.NOTESAVE

Event handler for the cancel button on the note form. Closes the form.

Used by: noteform constructor

V1.0 - 28 May 2019
-------------------------------------------------------------------------------}
procedure TNoteForm.noteSave(Sender: TObject);
begin
  BackMemo.Lines.SaveToFile(BackFileName + '.note.txt');
  ProgressFm.AddBtn.Caption:= 'Edit Note';
  Close;
end; //end procedure TNoteForm.noteSave

end.

