{ FoxClone
  Copyright (C) 2019 - 2021 Andy Hardwick
  This source is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free
  Software Foundation; either version 2 of the License, or (at your option)
  any later version.
  This code is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.
  A copy of the GNU General Public License is available on the World Wide Web
  at <http://www.gnu.org/copyleft/gpl.html>. You can also obtain it by writing
  to the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  Boston, MA 02110-1335, USA.
}

{-------------------------------------------------------------------------------
INCLUDE FILE SETTINGSTAB.INC

Includes all procedures associated with the settings tab on the mainform.

Changes:

V1.0 - created 11 Jan 2021
-------------------------------------------------------------------------------}

{-------------------------------------------------------------------------------
PROCEDURE CREATESETTINGSPAGE
Creates the settings page objects - checkboxes for
 backing up the partition table
 file compresssion + combobox for the compression level
 splitting backup files + an editbox for the split file size
plus associated labels

Used by: the mainform constructor Create

V1.1 minor adjustment of objects for visual appearance in the iso running ubuntu

V1.0 - 15 Oct 19
V1.1 - 22 Nov 19
V1.2 - 10 Jan 20, partition table checkbox removed

Note - while the partition table checkbox has been removed, the associated procedures/functions and
variables have not been removed from the code - TBD.
-------------------------------------------------------------------------------}
procedure TMainFm.CreateSettingsPage;
const
  marginleft = 15;
var
  i : integer;
begin
  {---------------------------------------------------------------------------
  Image and main title
  ---------------------------------------------------------------------------}
  SettingsImg:=TImage.Create(Self);
  with SettingsImg do begin
       Parent:=PageCtrl.Page[4];
       Left:= 700;
       Top:= 10;
       Picture.LoadFromFile(SettingsImgFile);
  end;
  //Main title for the tab
  SettingsLbl:= TLabel.Create(Self);
  with SettingsLbl do
       begin
         Parent:= PageCtrl.Page[4];
         Top:= 20;
         Left:= marginleft;
         Width:= 150;
         Height:= 16;
         Caption:= 'Settings';
         Font.Size:= 14;
       end;
  {---------------------------------------------------------------------------
  Compression checkbox and compression level
  ---------------------------------------------------------------------------}
  CompressionChkBox:= TCheckBox.Create(Self);
  with CompressionChkBox do
       begin
         Parent:= PageCtrl.Page[4];
         Top:= SettingsLbl.Top + 100;
         Left:= marginleft;
         Width:= 150;
         Height:= 16;
         ShowHint:= true;
         Hint:= 'Compression can reduce file size by 50% but with increased backup times';
         Caption:= 'Compress backup files, compression level:';
         Checked:= settings.compress;
         OnClick:= @SettingsCompression;
      end;
  CompLvlComboBox:= TComboBox.Create(Self);
  with CompLvlComboBox do
       begin
         Parent := PageCtrl.Page[4];
         //was 270 changed for visual appearance in the iso under ubuntu
         Left := marginleft + 280;
         Top	:= CompressionChkBox.Top - 4;
         Width := 40;
         Height := 20;
         Style := csDropDownList;
         Items.Add(' '); //so that level index starts from 1
         ShowHint:= true;
         Hint:= '1 = least compression, fastest time' + LF + '9 = most compression, longest time';
         OnChange := @SettingsCompLevel;
        end;
  for i:= 1 to 9 do  CompLvlComboBox.Items.Add(IntToStr(i));
  CompLvlComboBox.ItemIndex:= settings.complevel;
  {---------------------------------------------------------------------------
  Split files checkbox and file size
  ---------------------------------------------------------------------------}
  SplitCheckBox:= TCheckBox.Create(Self);
  with SplitCheckBox do
       begin
         Parent:= PageCtrl.Page[4];
         Top:= CompressionChkBox.Top + 40;
         Left:= marginleft;
         Width:= 150;
         Height:= 16;
         ShowHint:= true;
         Hint:= 'FAT32 systems have a max file size of 4GB minus 2 Bytes' + LF +
                'Older FAT or FAT16 file systems are limited to 2GB';
         //more spaces added
         Caption:= 'Split backup files, file size                     MB';
         Checked:= settings.split;
         OnClick:= @SettingsSplit;
       end;
  SplitFileSize:= TEdit.Create(Self);
  with SplitFileSize do
       begin
         Parent:= PageCtrl.Page[4];
         //was 165, changed for visual appearance in iso under ubuntu
         Left:= marginleft + 175;
         Top:= SplitCheckBox.Top - 3;
         Width:= 50;
         Height:= 20;
         ShowHint:= true;
         Hint:= 'FAT32 systems have a max file size of 4GB minus 2 Bytes';
         Text:= IntToStr(settings.splitsize);
         Alignment:= taRightJustify;
         NumbersOnly:= true; //doesn't work
         AutoSelect:= true; //selects all content of text box on click - doesn't work
         Enabled:= false;
         OnChange := @SettingsSplitSize;
       end;
  {---------------------------------------------------------------------------
  Reset button - resets all settings to default settings
  ---------------------------------------------------------------------------}
  ResetBtn:= TButton.Create(Self);
  with ResetBtn do
       begin
         Parent:= PageCtrl.Page[4];
         Width:= 110;
         Left:= marginleft;
         Top:= SplitCheckBox.Top + 60;
         Height:= 30;
         Show;
         Caption:= 'Reset to default';
         Enabled:= true;
         OnClick:= @SettingsDefault;
         Visible:= true;
       end;
  {---------------------------------------------------------------------------
  Quit button
  ---------------------------------------------------------------------------}
  SQuitBtn:= TButton.Create(Self);
  with SQuitBtn do
       begin
         Parent:= PageCtrl.Page[4];
         Width:= 80;
         Left:= 770 - 2 * Width - 10;
         Top:= 470;
         Height:= 30;
         Show;
         Caption:= 'Quit';
         Enabled:= true; //turn off until needed
         OnClick:= @QuitCK;
         Visible:= true; //not visible until needed
       end;
end; //procedure CreateSettingsPage
{-------------------------------------------------------------------------------
PROCEDURE - SETTINGSCOMPRESSION
Toggles whether backup files are compressed or not.
Default is compress

Used by: TMainFm.CreateSettingsPage

V1.0 - 27 May 2019
-------------------------------------------------------------------------------}
procedure TMainFm.SettingsCompression(Sender: TObject);
begin
  settings.compress:= CompressionChkBox.Checked;
  if settings.compress then CompLvlComboBox.Enabled:= true
  else CompLvlComboBox.Enabled:= false;
end; //procedure TMainFm.SettingsCompression
{-------------------------------------------------------------------------------
PROCEDURE - SETTINGSCOMPLEVEL
Reads the compression level value and updates the settings record
Default is level 2

Used by: TMainFm.CreateSettingsPage

V1.0 - 27 May 2019
-------------------------------------------------------------------------------}
procedure TMainFm.SettingsCompLevel(Sender: TObject);
begin
  settings.complevel:= CompLvlComboBox.ItemIndex;
end; //procedure TMainFm.SettingsCompLevel
{-------------------------------------------------------------------------------
PROCEDURE - SETTINGSSPLIT
Toggles whether backup files are split or not.
Default is no split.

Used by: TMainFm.CreateSettingsPage

V1.0 - 27 May 2019
-------------------------------------------------------------------------------}
procedure TMainFm.SettingsSplit(Sender: TObject);
begin
  settings.split:= SplitCheckBox.Checked;
  if settings.split then SplitFileSize.Enabled:= true
  else SplitFileSize.Enabled:= false;
end; //procedure TMainFm.SettingsSplit
{-------------------------------------------------------------------------------
PROCEDURE - SETTINGSSPLITSIZE
If image files are to be split parses the input in the split box to determine the split size.
Unfortunately the NumbersOnly property of tedit does not appear to work so this
procedure must parse the text entered and strip out any non-numeric characters

Used by: TMainFm.CreateSettingsPage

V1.0 - 27 May 2019
-------------------------------------------------------------------------------}
procedure TMainFm.SettingsSplitSize(Sender: TObject);
var
  testchar : char;
  pass : boolean;
begin
  for testchar in SplitFileSize.Text do
      begin
        pass:= testchar in ['0'..'9'];
        //strip out any non-numeric characters
        if not pass then SplitFileSize.Text:=ReplaceText(SplitFileSize.Text,testchar,'');
      end;
  if SplitFileSize.Text = '' then SplitFileSize.Text:= '0';
  settings.splitsize:= StrToInt(SplitFileSize.Text);
end; //procedure TMainFm.SettingsSplitSize
{-------------------------------------------------------------------------------
PROCEDURE - SETTINGSDEFAULT
Resets all settings back to their default values

Used by: TMainFm.CreateSettingsPage

V1.1 - 10 Jan 20, PartTableCheckBox removed
-------------------------------------------------------------------------------}
procedure TMainFm.SettingsDefault(Sender: TObject);
begin
  InitialSettings; //set the settings record back to default values
  CompressionChkBox.Checked:= settings.compress;
  SplitCheckBox.Checked:= settings.split;
  CompLvlComboBox.ItemIndex:= settings.complevel;
  SplitFileSize.Text:= IntToStr(settings.splitsize);
end; //procedure TMainFm.SettingsDefault



