{ FoxClone
  Copyright (C) 2019 - 2021 Andy Hardwick
  This source is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free
  Software Foundation; either version 2 of the License, or (at your option)
  any later version.
  This code is distributed in the hope that it will be useful, but WITHOUT ANY
  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.
  A copy of the GNU General Public License is available on the World Wide Web
  at <http://www.gnu.org/copyleft/gpl.html>. You can also obtain it by writing
  to the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  Boston, MA 02110-1335, USA.
}

{-------------------------------------------------------------------------------
INCLUDE FILE VERIFYTAB.INC

Includes all procedures associated with the verify tab on the mainform.

Changes:

V1.0 - created 11 Jan 2021
-------------------------------------------------------------------------------}

{-------------------------------------------------------------------------------
PROCEDURE CREATEVERIFYPAGE
Creates the verify page objects - three boxes for source drive (which drive is the
backup file on, source partition (which partition is the backup file in),
and contents of the backup, plus associated labels.
Two tbuttons, one to verify and the other to quit. There is also a note button
which is enabled if there is a note associated with the backup.

Used by: the mainform constructor Create

V1.3 - 11 Jan 21, created
-------------------------------------------------------------------------------}
procedure TMainFm.CreateVerifyPage;
begin
  //debug
  if debug then DebugOut(true,'TMainFm.CreateVerifyPage');
  //end debug
  {---------------------------------------------------------------------------
  Images and main title on the verify tab
  ---------------------------------------------------------------------------}
  CheckImg:=TImage.Create(Self);
  with CheckImg do begin
       Parent:=PageCtrl.Page[3];
       Left:= 690;
       Top:= 10;
       Picture.LoadFromFile(CheckImgFile);
  end;
  FileImg:=TImage.Create(Self);
  with FileImg do begin
       Parent:=PageCtrl.Page[3];
       Left:= 550;
       Top:= 5;
       Picture.LoadFromFile(FileImgFile);
  end;
  ArrowImg:=TImage.Create(Self);
  with ArrowImg do begin
       Parent:=PageCtrl.Page[3];
       Left:= 625;
       Top:= 25;
       Picture.LoadFromFile(ArrowImgFile);
  end;
  VerifyLbl := TLabel.Create(Self);
  with VerifyLbl do
       begin
         Parent:= PageCtrl.Page[3];
         Top:= 20;
         Left:= LeftChkBox1;
         Width:= 150;
         Height:= 16;
         Caption:= 'Verify Image File(s)';
         Font.Size:= 14;
         Show;
       end;
  {---------------------------------------------------------------------------
  Drive select tcheckbox, labels and event handlers
  ---------------------------------------------------------------------------}
  VBox1Lbl := TLabel.Create(Self);
  with VBox1Lbl do
       begin
         Parent := PageCtrl.Page[3];
         Top := TopChkBox1 - 20;
         Left := LeftChkBox1;
         Width := 150;
         Height := 16;
         Caption := '1 - Drive containing backup files:';
         Show;
       end;
  VChkBox1:= TCheckListBox.Create(Self);
  with VChkBox1 do
       begin
         Parent:= PageCtrl.Page[3];
         Left := LeftChkBox1;
         Top := TopChkBox1;
         Width := ChkBoxWidth;
         Height := ChkBoxHeight;
         ExtendedSelect:= false; //stops shift plus click
         MultiSelect:= false;//stops ctrl plus click
         //AllowGrayed:= true;
         //Color:= Yellow;
         ShowHint:= true;
         Hint:= DriveHint;
       end;
  //event handlers
  VChkBox1.OnClickCheck:= @VBox1CK;
  VChkBox1.OnClick:= @VBox1CK;
  {---------------------------------------------------------------------------
  Partition select tcheckbox, labels and event handlers
  ---------------------------------------------------------------------------}
  VBox2Lbl := TLabel.Create(Self);
  with RestBox2Lbl do
       begin
         Parent := PageCtrl.Page[3];
         Top := TopChkBox1 - 20;
         Left := LeftChkBox2;
         Width := 150;
         Height := 16;
         Caption := '2 - Partition containing backup file:';
         Show;
       end;
  VChkBox2:= TCheckListBox.Create(Self);
  with VChkBox2 do
       begin
         Parent:= PageCtrl.Page[3];
         Left:= LeftChkBox2;
         Top:= TopChkBox1;
         Width:= ChkBoxWidth;
         Height:= ChkBoxHeight;
         ExtendedSelect:= false; //stops shift plus click
         MultiSelect:= false;//stops ctrl plus click
         ShowHint:= true;
         Hint:= PartitionHint + LF + 'Only one partition can be selected';
         Enabled:= false;
       end;
  //event handlers
  VChkBox2.OnClickCheck:= @VBox2CK;
  VChkBox2.OnClick:= @VBox2CK;
  {---------------------------------------------------------------------------
  Contents of backup chklistbox, labels and event handlers
  ---------------------------------------------------------------------------}
  VBox3Lbl:= TLabel.Create(Self);
  with VBox3Lbl do
       begin
         Parent:= PageCtrl.Page[3];
         Top:= TopChkBox2 - 20;
         Left:= LeftChkBox1;
         Width:= 150;
         Height:= 16;
         Caption:= '3 - Contents of Backup:';
         Show;
       end;
  VChkBox3:= TCheckListBox.Create(Self);
  with VChkBox3 do
       begin
         Parent:= PageCtrl.Page[3];
         Left:= LeftChkBox1;
         Top:= TopChkBox2;
         Width:= ChkBoxWidth;
         Height:= ChkBoxHeight;
         ExtendedSelect:= false; //stops shift plus click
         MultiSelect:= false;//stops ctrl plus click
         Enabled:= false;
         ShowHint:= true;
         Hint:= 'Contents of the backup:' + LF + PartitionHint + LF + 'Multiple partitions can be selected';
       end;
  //event handlers
  VChkBox3.OnClickCheck:= @VBox3CK;
  VChkBox3.OnClick:= @VBox3CK;
  //Date the backup was taken
  VDateLbl := TLabel.Create(Self);
  with vDateLbl do
       begin
         Parent := PageCtrl.Page[3];
         Top := TopChkBox2 + ChkBoxHeight + 20;
         Left := LeftChkBox1;
         Width := 150;
         Height := 16;
         Caption := '';
         Visible:= false;
        end;
  {---------------------------------------------------------------------------
  Note button - enabled if a note is present in the backup
  ---------------------------------------------------------------------------}
  VNoteBtn:= TButton.Create(Self);
  with VNoteBtn do
       begin
         Parent:= PageCtrl.Page[3];
         Width:= 80;
         Left:= LeftChkBox1 + RestChkBox3.Width - 80;
         Top:= TopChkBox2 + ChkBoxHeight + 20;
         Height:= 30;
         Visible:= false;
         Caption:= 'View Note';
         Enabled:= false; //turn off until needed
         OnClick := @VNoteCK;
       end;
  {---------------------------------------------------------------------------
  Quit button
  ---------------------------------------------------------------------------}
  QuitBtn:= TButton.Create(Self);
  with QuitBtn do
       begin
         Parent:= PageCtrl.Page[3];
         Width:= 80;
         Left:= LeftChkBox2 + ChkBoxWidth - 2 * Width - 10;
         Top:= TopChkBox2 + ChkBoxHeight + 20;
         Height:= 30;
         Show;
         Caption:= 'Quit';
         Enabled:= true;
         OnClick := @QuitCK;
         Visible:= true;
       end;
  {---------------------------------------------------------------------------
  Verify button
  ---------------------------------------------------------------------------}
  VerifyBtn:= TButton.Create(Self);
  with VerifyBtn do
       begin
         Parent:= PageCtrl.Page[3];
         Width:= 80;
         Left:= LeftChkBox2 + ChkBoxWidth - Width;
         Top:= TopChkBox2 + ChkBoxHeight + 20;
         Height:= 30;
         Show;
         Caption:= 'Verify';
         Enabled:= false; //turn off until needed
         OnClick:= @VButtonCK;
       end;
end; // end procedure createrestorepage
{-------------------------------------------------------------------------------
PROCEDURE VBOX1CK
Event handler for checkbox 1 on the verify page, which is the source drive
containing the backup files.

Used by: CreateVerifyPage

V1.0 - 11 Jan 2021
-------------------------------------------------------------------------------}
procedure TMainFm.VBox1CK(Sender: TObject);
begin
  if VChkBox1.ItemIndex >= 0 then VBox1(VChkBox1.ItemIndex);
end; //end procedure TMainFm.VBox1CK
{-------------------------------------------------------------------------------
PROCEDURE VBOX2CK
Event handler for checkbox 2 on the verfiy page. This is the partition containing
the backup files. It is triggered by both the onclick and oncheck events.

Used by: CreateVerifyPage

V1.0 - 12 Jan 2021
-------------------------------------------------------------------------------}
procedure TMainFm.VBox2CK(Sender: TObject);
begin
  if VChkBox2.ItemIndex >= 0 then VBox2(VChkBox2.ItemIndex);
end; //end procedure TMainFm.VBox2CK
{-------------------------------------------------------------------------------
PROCEDURE VNOTECK
Event handler for note button. Initially it is disabled and is enabled elsewhere
if there is a note associated with the backup, the procedure creates the note
form and loads the note into it.

Used by: CreateVerifyPage

V1.0 - 12 Jan 2021
-------------------------------------------------------------------------------}
procedure TMainFm.VNoteCK(Sender: TObject);
var
  VNote : TNoteForm;
  NoteFname : string;
begin
  VNote:= TNoteForm.create(MainFm); //was self, changed to MainFm
  VNote.SaveButton.Enabled:= false;
  VNote.SaveButton.Visible:= false;
  VNote.CancelButton.Left:= 300;
  writeln('verify file name=',VerifyFileName);
  NoteFname:= copy(VerifyFileName,1,pos('.backup',VerifyFileName)-1) + '.note.txt';
  VNote.BackMemo.Lines.LoadFromFile(NoteFname);
  VNote.show;
end; //end procedure TMainFm.VNoteCK
{-------------------------------------------------------------------------------
PROCEDURE VBOX3CK
This is the event handler for checkbox 3 on the verify tab. It is triggered by
both the onclick and oncheck events.

Checkbox 3 displays the contents (partitions) of the backup selected.

VBox3CK checks that the selected partitons are valid - swap and extended partitions cannot be verified
and partclone.chkimg does not work with unknown partition types, i.e. backup images created with
partclone.dd.

Used by: CreateVerifyPage

V1.0 - 13 Jan 2021
-------------------------------------------------------------------------------}
procedure TMainFm.VBox3CK(Sender: TObject);
var
  i, source : integer;
begin
  if VChkBox3.ItemIndex >= 0 then
     source:= VChkBox3.ItemIndex;
     begin
       if source = 0 then
          begin
            VChkBox3.Checked[0]:= not VChkBox3.Checked[0];
            for i:= 1 to VChkBox3.count - 1 do if VChkBox3.Checked[0] then VChkBox3.Checked[i]:= true
                else VChkBox3.Checked[i]:= false;
            //now check each of the partitions, cannot verify extended, swap or unknown partitions
            for i:= 1 to VChkBox3.count - 1 do
                if (VSettings.NewParts[i].fs = 'swap') or
                   (VSettings.NewParts[i].fs = '<unknown>') or
                   (VSettings.NewParts[i].ptype = 'extended')
                then VChkBox3.Checked[i]:= false;
            VerifyBtn.enabled:= true;
          end
       else //process each item.
          begin
            VChkBox3.Checked[source]:= not VChkBox3.Checked[source];
            if (VSettings.NewParts[source].fs = 'swap') or
               (VSettings.NewParts[source].fs = '<unknown>') or
               (VSettings.NewParts[source].ptype = 'extended')
            then
              begin
                VChkBox3.Checked[source]:= false;
                 MessageDlg('Cannot verify unknown, swap'
                            + LF + 'or extended partitions',mtInformation,[mbOK],0)
              end
            else VerifyBtn.enabled:= true;
          end;
     end;
end; //end procedure TMainFm.VBox3CK
{-------------------------------------------------------------------------------
PROCEDURE VBUTTONCK
Event handler for the verify button. All it does is call VerifyParts.

Used by: CreateVerifyPage

V1.0 - 14 Jan 2021
-------------------------------------------------------------------------------}
procedure TMainFm.VButtonCK(Sender: TObject);
begin
  VerifyParts;
end; //end procedure TMainFm.VButtonCK



